pub const fn blocking<'src, I, O>(
f: impl FnOnce(I) -> O + Send + 'src,
) -> impl Task<'src, I, O>Expand description
Treat the wrapped closure as performing work which will block, for example
on an OS call, for which a Mode can implement scheduling behavior.